@@ -1,7 +1,7 @@
 #' Sampling for the Apparent Error Rate
 #'
 #' When building a model on a data set and re-predicting the same data, the
-#'   performance estimate from those predictions is often call the
+#'   performance estimate from those predictions is often called the
 #'   "apparent" performance of the model. This estimate can be wildly
 #'   optimistic. "Apparent sampling" here means that the analysis and
 #'   assessment samples are the same. These resamples are sometimes used in
@@ -24,8 +24,7 @@ apparent <- function(data, ...) {
 
   split_objs <-
     add_class(split_objs,
-              cls = c("apparent", "rset"),
-              at_end = FALSE)
+              cls = c("apparent", "rset"))
 
   split_objs
 }
