@@ -60,7 +60,7 @@ initial_split <- function(data, prop = 3/4, strata = NULL, breaks = 4, ...) {
 }
 
 #' @rdname initial_split
-#' @param lag A value to include an lag between the assessment
+#' @param lag A value to include a lag between the assessment
 #'  and analysis set. This is useful if lagged predictors will be used
 #'  during training and testing.
 #' @export
@@ -80,7 +80,13 @@ initial_time_split <- function(data, prop = 3/4, lag = 0, ...) {
     stop("`lag` must be less than or equal to the number of training observations.", call. = FALSE)
   }
 
-  rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
+  split  <- rsplit(data, 1:n_train, (n_train + 1 - lag):nrow(data))
+  splits <- list(split)
+  ids    <- "Resample1"
+  rset   <- new_rset(splits, ids)
+
+  rset$splits[[1]]
+
 }
 
 #' @rdname initial_split
