@@ -26,7 +26,7 @@
 #' @export
 #' @return A tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and
 #'  `data.frame`. The results include a column for the data split objects and
-#'  one or more identification variables. For a single repeats, there will be
+#'  one or more identification variables. For a single repeat, there will be
 #'  one column called `id` that has a character string with the fold identifier.
 #'  For repeats, `id` is the repeat number and an additional column called `id2`
 #'  that contains the fold information (within repeat).
@@ -36,30 +36,30 @@
 #' vfold_cv(mtcars, v = 10, repeats = 2)
 #'
 #' library(purrr)
-#' iris2 <- iris[1:130, ]
+#' data(wa_churn, package = "modeldata")
 #'
 #' set.seed(13)
-#' folds1 <- vfold_cv(iris2, v = 5)
+#' folds1 <- vfold_cv(wa_churn, v = 5)
 #' map_dbl(folds1$splits,
 #'         function(x) {
-#'           dat <- as.data.frame(x)$Species
-#'           mean(dat == "virginica")
+#'           dat <- as.data.frame(x)$churn
+#'           mean(dat == "Yes")
 #'         })
 #'
 #' set.seed(13)
-#' folds2 <- vfold_cv(iris2, strata = "Species", v = 5)
+#' folds2 <- vfold_cv(wa_churn, strata = "churn", v = 5)
 #' map_dbl(folds2$splits,
 #'         function(x) {
-#'           dat <- as.data.frame(x)$Species
-#'           mean(dat == "virginica")
+#'           dat <- as.data.frame(x)$churn
+#'           mean(dat == "Yes")
 #'         })
 #'
 #' set.seed(13)
-#' folds3 <- vfold_cv(iris2, strata = "Petal.Length", breaks = 6, v = 5)
+#' folds3 <- vfold_cv(wa_churn, strata = "tenure", breaks = 6, v = 5)
 #' map_dbl(folds3$splits,
 #'         function(x) {
-#'           dat <- as.data.frame(x)$Species
-#'           mean(dat == "virginica")
+#'           dat <- as.data.frame(x)$churn
+#'           mean(dat == "Yes")
 #'         })
 #' @export
 vfold_cv <- function(data, v = 10, repeats = 1, strata = NULL, breaks = 4, ...) {
@@ -85,7 +85,7 @@ vfold_cv <- function(data, v = 10, repeats = 1, strata = NULL, breaks = 4, ...)
     }
   }
 
-  ## We remove the holdout indicies since it will save space and we can
+  ## We remove the holdout indices since it will save space and we can
   ## derive them later when they are needed.
 
   split_objs$splits <- map(split_objs$splits, rm_out)
@@ -100,11 +100,6 @@ vfold_cv <- function(data, v = 10, repeats = 1, strata = NULL, breaks = 4, ...)
            subclass = c("vfold_cv", "rset"))
 }
 
-# Get the indices of the analysis set from the assessment set
-vfold_complement <- function(ind, n) {
-  list(analysis = setdiff(1:n, ind),
-       assessment = ind)
-}
 
 vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4) {
   if (!is.numeric(v) || length(v) != 1)
@@ -125,7 +120,7 @@ vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4) {
     indices <- split_unnamed(stratas$idx, stratas$folds)
   }
 
-  indices <- lapply(indices, vfold_complement, n = n)
+  indices <- lapply(indices, default_complement, n = n)
 
   split_objs <- purrr::map(indices, make_splits, data = data, class = "vfold_split")
   tibble::tibble(splits = split_objs,
